@@ -174,12 +174,7 @@ startup_volume_mount_cb (GObject *source_object,
 			 GAsyncResult *res,
 			 gpointer user_data)
 {
-	if (!g_volume_mount_finish (G_VOLUME (source_object), res, NULL)) {
-		/* There was an error mounting the volume, so we
-		   clear the automount part. This is otherwise done
-		   when the mount is added to the volume monitor */
-		g_object_set_data (source_object, "nautilus-automounted", GINT_TO_POINTER (0));
-	}
+	g_volume_mount_finish (G_VOLUME (source_object), res, NULL);
 }
 
 static void
@@ -205,8 +200,6 @@ automount_all_volumes (NautilusApplication *application)
 				g_object_unref (mount);
 				continue;
 			}
-			
-			nautilus_inhibit_autorun_for_volume (volume);
 
 			/* pass NULL as GMountOperation to avoid user interaction */
 			g_volume_mount (volume, 0, NULL, NULL, startup_volume_mount_cb, NULL);
@@ -279,6 +272,11 @@ nautilus_application_destroy (BonoboObject *object)
 	}
 	bonobo_object_unref (application->shell);
 
+	if (application->automount_idle_id != 0) {
+		g_source_remove (application->automount_idle_id);
+		application->automount_idle_id = 0;
+	}
+
 	EEL_CALL_PARENT (BONOBO_OBJECT_CLASS, destroy, (object));
 }
 
@@ -407,6 +405,17 @@ menu_provider_init_callback (void)
         nautilus_module_extension_list_free (providers);
 }
 
+static gboolean
+automount_all_volumes_idle_cb (gpointer data)
+{
+	NautilusApplication *application = NAUTILUS_APPLICATION (data);
+
+	automount_all_volumes (application);
+
+	application->automount_idle_id = 0;
+	return FALSE;
+}
+
 static void
 finish_startup (NautilusApplication *application)
 {
@@ -447,7 +456,10 @@ finish_startup (NautilusApplication *application)
 	g_list_foreach (drives, (GFunc) g_object_unref, NULL);
 	g_list_free (drives);
 
-	automount_all_volumes (application);
+	application->automount_idle_id = 
+		g_idle_add_full (G_PRIORITY_LOW,
+				 automount_all_volumes_idle_cb,
+				 application, NULL);
 }
 
 static void
@@ -923,17 +935,18 @@ find_parent_spatial_window (NautilusSpatialWindow *window)
 	while (parent_file) {
 		NautilusSpatialWindow *parent_window;
 
-		/* Stop at the desktop directory, as this is the
-		 * conceptual root of the spatial windows */
-		if (nautilus_file_is_desktop_directory (parent_file)) {
-			nautilus_file_unref (parent_file);
-			return NULL;
-		}
-
 		location = nautilus_file_get_location (parent_file);
 		parent_window = nautilus_application_get_existing_spatial_window (location);
 		g_object_unref (location);
 
+		/* Stop at the desktop directory if it's not explicitely opened
+		 * in a spatial window of its own.
+		 */
+		if (nautilus_file_is_desktop_directory (parent_file) && !parent_window) {
+			nautilus_file_unref (parent_file);
+			return NULL;
+		}
+
 		if (parent_window) {
 			nautilus_file_unref (parent_file);
 			return parent_window;
@@ -1333,7 +1346,7 @@ volume_added_callback (GVolumeMonitor *monitor,
 	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT) &&
 	    g_volume_should_automount (volume) &&
 	    g_volume_can_mount (volume)) {
-		nautilus_file_operations_mount_volume (NULL, volume);
+		nautilus_file_operations_mount_volume (NULL, volume, TRUE);
 	}
 }
 
@@ -1459,7 +1472,7 @@ mount_removed_callback (GVolumeMonitor *monitor,
 
 			location = nautilus_window_get_location (window);
 
-			if (g_file_contains_file (root, location)) {
+			if (g_file_equal(location, root) || g_file_has_prefix (location, root)) {
 				close_list = g_list_prepend (close_list, window);
 			} 
 			g_object_unref (location);
